collector

package
v0.1.0-alpha Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 29, 2022 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetNamespacedResources

GetNamespacedResources performs the LIST action over a namespaced resource type and returns all instances of it as a `Unstructured.UnstructuredList` object.

func GetServerResources

GetServerResources performs the LIST action over a resource type and returns all instances of it as a `Unstructured.UnstructuredList` object.

Types

type ClusterState

type ClusterState = map[string]unstructured.UnstructuredList

func GetNamespacedState

func GetNamespacedState(disClient *discovery.DiscoveryClient, dynClient *dynamic.Interface, ns string) ClusterState

GetNamespacedState returns the state `ClusterState` of all the resources present in the namespace `ns` of the kubernetes cluster accessible using `disClient` and `dynClient`.

func GetState

func GetState(disClient *discovery.DiscoveryClient, dynClient *dynamic.Interface) ClusterState

GetState returns the state `ClusterState` of all the resources instantiated in the kubernetes cluster accessible using `disClient` and `dynClient`.

Jump to