Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetNamespacedResources ¶
func GetNamespacedResources(cli dynamic.Interface, gvr schema.GroupVersionResource, ns string) unstructured.UnstructuredList
GetNamespacedResources performs the LIST action over a namespaced resource type and returns all instances of it as a `Unstructured.UnstructuredList` object.
func GetServerResources ¶
func GetServerResources(cli dynamic.Interface, gvr schema.GroupVersionResource) unstructured.UnstructuredList
GetServerResources performs the LIST action over a resource type and returns all instances of it as a `Unstructured.UnstructuredList` object.
Types ¶
type ClusterState ¶
type ClusterState = map[string]unstructured.UnstructuredList
func GetNamespacedState ¶
func GetNamespacedState(disClient *discovery.DiscoveryClient, dynClient *dynamic.Interface, ns string) ClusterState
GetNamespacedState returns the state `ClusterState` of all the resources present in the namespace `ns` of the kubernetes cluster accessible using `disClient` and `dynClient`.
func GetState ¶
func GetState(disClient *discovery.DiscoveryClient, dynClient *dynamic.Interface) ClusterState
GetState returns the state `ClusterState` of all the resources instantiated in the kubernetes cluster accessible using `disClient` and `dynClient`.
Click to show internal directories.
Click to hide internal directories.